
.. _l-README:

README
======

.. image:: https://travis-ci.org/sdpython/lightmlboard.svg?branch=master
    :target: https://travis-ci.org/sdpython/lightmlboard
    :alt: Build status

.. image:: https://ci.appveyor.com/api/projects/status/6g0xro11tmc6t05d?svg=true
    :target: https://ci.appveyor.com/project/sdpython/lightmlboard
    :alt: Build Status Windows

.. image:: https://circleci.com/gh/sdpython/lightmlboard/tree/master.svg?style=svg
    :target: https://circleci.com/gh/sdpython/lightmlboard/tree/master

.. image:: https://badge.fury.io/py/lightmlboard.svg
    :target: http://badge.fury.io/py/lightmlboard

.. image:: https://img.shields.io/badge/license-MIT-blue.svg
    :alt: MIT License
    :target: http://opensource.org/licenses/MIT

.. image:: https://requires.io/github/sdpython/lightmlboard/requirements.svg?branch=master
     :target: https://requires.io/github/sdpython/lightmlboard/requirements/?branch=master
     :alt: Requirements Status

.. image:: https://codecov.io/github/sdpython/lightmlboard/coverage.svg?branch=master
    :target: https://codecov.io/github/sdpython/lightmlboard?branch=master

.. image:: http://img.shields.io/github/issues/sdpython/lightmlboard.png
    :alt: GitHub Issues
    :target: https://github.com/sdpython/lightmlboard/issues

.. image:: https://badge.waffle.io/sdpython/lightmlboard.png?label=ready&title=Ready
    :alt: Waffle
    :target: https://waffle.io/lightmlboard/lightmlboard

.. image:: http://www.xavierdupre.fr/app/lightmlboard/helpsphinx/_images/nbcov.png
    :target: http://www.xavierdupre.fr/app/lightmlboard/helpsphinx/all_notebooks_coverage.html
    :alt: Notebook Coverage

*lightmlboard* implements a server to hold the result of a machine learning competition.

*not ready*

**Links:**

* `GitHub/lightmlboard <https://github.com/sdpython/lightmlboard/>`_
* `documentation <http://www.xavierdupre.fr/app/lightmlboard/helpsphinx/index.html>`_
* `Blog <http://www.xavierdupre.fr/app/lightmlboard/helpsphinx/blog/main_0000.html#ap-main-0>`_
